@@ -13,7 +13,8 @@
 #' @param add.path Character.
 #' Path to additional dictionaries to be found.
 #' DOES NOT search recursively (through all folders in path)
-#' to avoid time intensive search
+#' to avoid time intensive search.
+#' Set to \code{"choose"} to open an interactive directory explorer
 #' 
 #' @return 
 #' 
@@ -43,11 +44,12 @@
 #' 
 #' @seealso \code{\link{append.dictionary}} to create a new dictionary,
 #' \code{\link{dictionaries}} to identify dictionaries in
-#' \code{\link{SemNetDictionaries}}
-#' 
+#' \code{\link{SemNetDictionaries}}, and
+#'  \code{\link{load.dictionaries}} to load multiple dictionaries
+#'   
 #' @export
-#Find Dictionaries
-# Updated 03.04.2020
+# Find Dictionaries
+# Updated 08.09.2020
 find.dictionaries <- function(..., add.path = NULL)
 {
     #grab dictionary list
@@ -269,6 +271,9 @@ find.dictionaries <- function(..., add.path = NULL)
         #search additional path
         if(!is.null(add.path))
         {
+            if(add.path == "choose")
+            {add.path <- easycsv::choose_dir()}
+            
             if(dir.exists(add.path))
             {
                 #search through path
